@@ -23,8 +23,8 @@ Speedo::Speedo(QWidget *parent) :
 
     //ui->lcdNumber_3->setDigitCount(7);
     //ui->lcdNumber_2->setDigitCount(7);
-    ui->lcdNumber->setDigitCount(7);
-    ui->lcdNumber_4->setDigitCount(10);
+    ui->lcdNumber->setDigitCount(10);
+    //ui->lcdNumber_4->setDigitCount(10);
 
     // load total distance and unit setting from a file
     FILE *fp=fopen("/home/user/.speedrec","r");
@@ -109,7 +109,7 @@ void Speedo::updateLocation()
         //ui->label->setText("km/h");
         //ui->label_2->setText("km (trip)");
         //ui->label_3->setText("km");
-        ui->label_5->setText("km/h");
+        //ui->label_5->setText("km/h");
         d_speed=(int)speed;
         d_trip = trip;
         d_total=total;
@@ -126,7 +126,7 @@ void Speedo::updateLocation()
         //ui->label->setText("mph");
         //ui->label_2->setText("mi (trip)");
         //ui->label_3->setText("mi");
-        ui->label_5->setText("mph");
+        //ui->label_5->setText("mph");
 
     }
 
@@ -148,7 +148,7 @@ void Speedo::updateLocation()
     ui->lcdNumber->display(QString(buf));
     ui->label->setText(text);
     }
-    else
+    else if(display==2)
     {
     sprintf(buf,"%.2f",d_total);
     // replace , with . for QLcdNumber
@@ -157,24 +157,34 @@ void Speedo::updateLocation()
     ui->lcdNumber->display(QString(buf));
     ui->label->setText(sUnit);
     }
+    else if(display==3)
+    {
     sprintf(buf,"%.2f",d_average);
     // replace , with . for QLcdNumber
     for(unsigned int i=0;i<strlen(buf);i++){
         if(buf[i]==',')buf[i]='.';}
-    ui->lcdNumber_5->display(QString(buf));
+    ui->lcdNumber->display(QString(buf));
+    QString text=sUnit+"/h (avg.speed)";
+    ui->label->setText(text);
+    }
 
 }
 
 void Speedo::updateTime()
 {
 
-char buf[80];char h[3],m[3],s[3];
-if(hour<10)sprintf(h,"0%d",hour);else sprintf(h,"%d",hour);
-if(min<10)sprintf(m,"0%d",min);else sprintf(m,"%d",min);
-if(sec<10)sprintf(s,"0%d",sec);else sprintf(s,"%d",sec);
+    if(display==4)
+    {
+        char buf[80];char h[3],m[3],s[3];
+        if(hour<10)sprintf(h,"0%d",hour);else sprintf(h,"%d",hour);
+        if(min<10)sprintf(m,"0%d",min);else sprintf(m,"%d",min);
+        if(sec<10)sprintf(s,"0%d",sec);else sprintf(s,"%d",sec);
 
-sprintf(buf,"%s.%s.%s.%d",h,m,s,tensofsec);
-ui->lcdNumber_4->display(QString(buf));
+        sprintf(buf,"%s.%s.%s.%d",h,m,s,tensofsec);
+        ui->lcdNumber->display(QString(buf));
+        ui->label->setText("");
+
+    }
     if(!started)return;
     if(paused)return;
     tensofsec++;
@@ -200,7 +210,7 @@ void Speedo::on_pushButton_2_clicked()
 
 void Speedo::on_startTimeButton_clicked()
 {
-    started=1;paused=0;
+    started=1;paused=0;display=4;
 
 }
 
@@ -209,13 +219,13 @@ void Speedo::on_pauseTimeButton_clicked()
     if(paused){
         hour=min=sec=tensofsec=seconds=0;started=0;average_speed=0;
     }
-    paused=1-paused;
+    paused=1-paused;display=4;
 
 }
 
 void Speedo::on_pushButton_3_clicked()
 {
     display++;
-    if(display>2)
+    if(display>4)
         display=0;
 }
